==> anwiba-commons-swing-core-1.1.121-sources.jar: net/anwiba/commons/swing/table/renderer/LocalDateTimeTableCellRenderer.java <==
/*
 * #%L
 * anwiba commons swing
 * %%
 * Copyright (C) 2007 - 2016 Andreas Bartels
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation, either version 2.1 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Lesser Public License for more details.
 *
 * You should have received a copy of the GNU General Lesser Public
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/lgpl-2.1.html>.
 * #L%
 */
package net.anwiba.commons.swing.table.renderer;

import java.awt.Component;
import java.time.LocalDateTime;

import javax.swing.JTable;
import javax.swing.SwingConstants;
import javax.swing.table.DefaultTableCellRenderer;

import net.anwiba.commons.lang.object.ObjectUtilities;
import net.anwiba.commons.utilities.time.LocalDateTimeUtilities;

@SuppressWarnings("serial")
public class LocalDateTimeTableCellRenderer extends DefaultTableCellRenderer {

  public LocalDateTimeTableCellRenderer() {
  }

  @Override
  public final Component getTableCellRendererComponent(
      final JTable table,
      final Object value,
      final boolean isSelected,
      final boolean hasFocus,
      final int row,
      final int column) {
    super.getTableCellRendererComponent(table, value, isSelected, hasFocus, row, column);
    setHorizontalAlignment(SwingConstants.RIGHT);
    if (value instanceof LocalDateTime) {
      final LocalDateTime time = (LocalDateTime) value;
      setText(LocalDateTimeUtilities.toString(time));
      return this;
    }
    setText(ObjectUtilities.toString(value));
    return this;
  }
}

==> anwiba-commons-swing-core-1.2.50-sources.jar: net/anwiba/commons/swing/table/renderer/LocalDateTimeTableCellRenderer.java <==
/*
 * #%L
 * anwiba commons swing
 * %%
 * Copyright (C) 2007 - 2016 Andreas Bartels
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation, either version 2.1 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Lesser Public License for more details.
 *
 * You should have received a copy of the GNU General Lesser Public
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/lgpl-2.1.html>.
 * #L%
 */
package net.anwiba.commons.swing.table.renderer;

import java.awt.Component;
import java.time.LocalDateTime;

import javax.swing.JTable;
import javax.swing.SwingConstants;
import javax.swing.table.DefaultTableCellRenderer;

import net.anwiba.commons.lang.object.ObjectUtilities;
import net.anwiba.commons.utilities.time.LocalDateTimeUtilities;

@SuppressWarnings("serial")
public class LocalDateTimeTableCellRenderer extends DefaultTableCellRenderer {

  public LocalDateTimeTableCellRenderer() {
  }

  @Override
  public final Component getTableCellRendererComponent(
      final JTable table,
      final Object value,
      final boolean isSelected,
      final boolean hasFocus,
      final int row,
      final int column) {
    super.getTableCellRendererComponent(table, value, isSelected, hasFocus, row, column);
    setHorizontalAlignment(SwingConstants.LEFT);
    if (value instanceof LocalDateTime) {
      final LocalDateTime time = (LocalDateTime) value;
      setText(LocalDateTimeUtilities.toString(time));
      return this;
    }
    setText(ObjectUtilities.toString(value));
    return this;
  }
}
